@@ -165,19 +165,35 @@ C<method set : void ($string : string);>
 
 Sets the string $string.
 
+=head2 compare_string
+
+C<method compare_string : int ($string : string);>
+
+The return value is the same as the return value of C<cmp> operator given C<$self-E<gt>to_string> and $string.
+
+=head2 equals_string
+
+C<method equals_string : int ($string : string);>
+
+If the string contained in the StringBuffer instance is equal to the string $string, returns 1, otherwise returns 0.
+
 =head2 clone
 
 C<method clone ();>
 
 Clones this string buffer and returns it.
 
+This method is a method implementation for L<Cloneable|SPVM::Cloneable> interface.
+
 =head2 cmp
 
 C<method cmp : int ($a : L<StringBuffer|SPVM::StringBuffer>, $b : L<StringBuffer|SPVM::StringBuffer>);>
 
 Compares two L<StringBuffer|SPVM::StringBuffer> and returns its result.
 
-The result is equal to the return value of C<cmp> operator given C<$a-E<gt>to_string> or undef(if $a is undef) and C<$b-E<gt>to_string> or undef(if $b is undef).
+The return value is the same as the return value of C<cmp> operator given C<$a-E<gt>to_string> or undef(if $a is undef) and C<$b-E<gt>to_string> or undef(if $b is undef).
+
+This method is a method implementation for L<Comparable|SPVM::Comparable> interface.
 
 =head2 eq
 
@@ -195,6 +211,20 @@ If only $b is not defined, returns 0.
 
 If both $a and $b is not defined, returns 1.
 
+This method is a method implementation for L<EqualityCheckable|SPVM::EqualityCheckable> interface.
+
+=head2 substr
+
+C<method substr : string ($offset : int, $length : int = -1);>
+
+Calls L<Fn#substr|SPVM::Fn/"substr"> method given the value of L</"string"> field, $offset, $length, and returns its return value.
+
+Exceptions:
+
+The offset $offset + the length $length must be less than or equal to the value of length field. Otherwise an exception is thrown.
+
+Exceptions thrown by L<Fn#substr|SPVM::Fn/"substr"> method could be thrown.
+
 =head1 Copyright & License
 
 Copyright (c) 2023 Yuki Kimoto
